@@ -4,14 +4,15 @@ import re
 import cmudict
 import syllables
 
+
 def test_estimate():
-    EXPECTED_ACCURACY = .75
+    EXPECTED_ACCURACY = 0.75
     hits = []
     misses = []
 
-    d = cmudict.dict()
-    for word in d:
-        phones = d[word][0]
+    dictionary = cmudict.dict()
+    for word in dictionary:
+        phones = dictionary[word][0]
         cmudict_syllables = 0
         for phone in phones:
             if re.match(r"\w*[012]$", phone):
@@ -26,6 +27,9 @@ def test_estimate():
     miss = len(misses)
     total = hit + miss
     ACCURACY = hit / total
-    if (ACCURACY < EXPECTED_ACCURACY):
-        raise AssertionError('syllables.estimate(): Expected accuracy of {0}, got {1}.'.format(
-            EXPECTED_ACCURACY, ACCURACY))
+    if ACCURACY < EXPECTED_ACCURACY:
+        raise AssertionError(
+            "syllables.estimate(): Expected accuracy of {0}, got {1}.".format(
+                EXPECTED_ACCURACY, ACCURACY
+            )
+        )
